# Installation

## Stable release

To install Geobay, run this command in your terminal:

```
pip install geobay
```

This is the preferred method to install GeoProject510, as it will always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

## From sources

To install Geobay from sources, run this command in your terminal:

```
pip install git+https://github.com/Caseyshea96/geobay
```
